# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
ElSLib module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_elslib.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _ElSLib
else:
    import _ElSLib

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _ElSLib.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _ElSLib.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _ElSLib.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _ElSLib.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _ElSLib.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _ElSLib.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _ElSLib.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _ElSLib.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _ElSLib.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _ElSLib.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _ElSLib.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _ElSLib.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _ElSLib.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _ElSLib.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _ElSLib.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _ElSLib.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _ElSLib.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _ElSLib:
_ElSLib.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _ElSLib.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection

from enum import IntEnum
from OCC.Core.Exception import *



class elslib(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def ConeD0(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        Pos: gp_Ax3
        Radius: float
        SAngle: float
        P: gp_Pnt

        Returns
        -------
        None

        """
        return _ElSLib.elslib_ConeD0(*args)

    @staticmethod
    def ConeD1(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        Pos: gp_Ax3
        Radius: float
        SAngle: float
        P: gp_Pnt
        Vu: gp_Vec
        Vv: gp_Vec

        Returns
        -------
        None

        """
        return _ElSLib.elslib_ConeD1(*args)

    @staticmethod
    def ConeD2(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        Pos: gp_Ax3
        Radius: float
        SAngle: float
        P: gp_Pnt
        Vu: gp_Vec
        Vv: gp_Vec
        Vuu: gp_Vec
        Vvv: gp_Vec
        Vuv: gp_Vec

        Returns
        -------
        None

        """
        return _ElSLib.elslib_ConeD2(*args)

    @staticmethod
    def ConeD3(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        Pos: gp_Ax3
        Radius: float
        SAngle: float
        P: gp_Pnt
        Vu: gp_Vec
        Vv: gp_Vec
        Vuu: gp_Vec
        Vvv: gp_Vec
        Vuv: gp_Vec
        Vuuu: gp_Vec
        Vvvv: gp_Vec
        Vuuv: gp_Vec
        Vuvv: gp_Vec

        Returns
        -------
        None

        """
        return _ElSLib.elslib_ConeD3(*args)

    @staticmethod
    def ConeDN(*args) -> "gp_Vec":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        Pos: gp_Ax3
        Radius: float
        SAngle: float
        Nu: int
        Nv: int

        Returns
        -------
        gp_Vec

        """
        return _ElSLib.elslib_ConeDN(*args)

    @staticmethod
    def ConeParameters(*args) -> "Standard_Real &, Standard_Real &":
        r"""
        Parametrization p (u, v) = location + v * zdirection + (radius + v * tan (semiangle)) * (cos(u) * xdirection + sin(u) * ydirection).

        Parameters
        ----------
        Pos: gp_Ax3
        Radius: float
        SAngle: float
        P: gp_Pnt

        Returns
        -------
        U: float
        V: float

        """
        return _ElSLib.elslib_ConeParameters(*args)

    @staticmethod
    def ConeUIso(*args) -> "gp_Lin":
        r"""
        Compute the u isoparametric gp_lin of the cone.

        Parameters
        ----------
        Pos: gp_Ax3
        Radius: float
        SAngle: float
        U: float

        Returns
        -------
        gp_Lin

        """
        return _ElSLib.elslib_ConeUIso(*args)

    @staticmethod
    def ConeVIso(*args) -> "gp_Circ":
        r"""
        Compute the v isoparametric gp_circ of the cone.

        Parameters
        ----------
        Pos: gp_Ax3
        Radius: float
        SAngle: float
        V: float

        Returns
        -------
        gp_Circ

        """
        return _ElSLib.elslib_ConeVIso(*args)

    @staticmethod
    def ConeValue(*args) -> "gp_Pnt":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        Pos: gp_Ax3
        Radius: float
        SAngle: float

        Returns
        -------
        gp_Pnt

        """
        return _ElSLib.elslib_ConeValue(*args)

    @staticmethod
    def CylinderD0(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        Pos: gp_Ax3
        Radius: float
        P: gp_Pnt

        Returns
        -------
        None

        """
        return _ElSLib.elslib_CylinderD0(*args)

    @staticmethod
    def CylinderD1(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        Pos: gp_Ax3
        Radius: float
        P: gp_Pnt
        Vu: gp_Vec
        Vv: gp_Vec

        Returns
        -------
        None

        """
        return _ElSLib.elslib_CylinderD1(*args)

    @staticmethod
    def CylinderD2(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        Pos: gp_Ax3
        Radius: float
        P: gp_Pnt
        Vu: gp_Vec
        Vv: gp_Vec
        Vuu: gp_Vec
        Vvv: gp_Vec
        Vuv: gp_Vec

        Returns
        -------
        None

        """
        return _ElSLib.elslib_CylinderD2(*args)

    @staticmethod
    def CylinderD3(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        Pos: gp_Ax3
        Radius: float
        P: gp_Pnt
        Vu: gp_Vec
        Vv: gp_Vec
        Vuu: gp_Vec
        Vvv: gp_Vec
        Vuv: gp_Vec
        Vuuu: gp_Vec
        Vvvv: gp_Vec
        Vuuv: gp_Vec
        Vuvv: gp_Vec

        Returns
        -------
        None

        """
        return _ElSLib.elslib_CylinderD3(*args)

    @staticmethod
    def CylinderDN(*args) -> "gp_Vec":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        Pos: gp_Ax3
        Radius: float
        Nu: int
        Nv: int

        Returns
        -------
        gp_Vec

        """
        return _ElSLib.elslib_CylinderDN(*args)

    @staticmethod
    def CylinderParameters(*args) -> "Standard_Real &, Standard_Real &":
        r"""
        Parametrization p (u, v) = location + v * zdirection + radius * (cos(u) * xdirection + sin (u) * ydirection).

        Parameters
        ----------
        Pos: gp_Ax3
        Radius: float
        P: gp_Pnt

        Returns
        -------
        U: float
        V: float

        """
        return _ElSLib.elslib_CylinderParameters(*args)

    @staticmethod
    def CylinderUIso(*args) -> "gp_Lin":
        r"""
        Compute the u isoparametric gp_lin of the cylinder.

        Parameters
        ----------
        Pos: gp_Ax3
        Radius: float
        U: float

        Returns
        -------
        gp_Lin

        """
        return _ElSLib.elslib_CylinderUIso(*args)

    @staticmethod
    def CylinderVIso(*args) -> "gp_Circ":
        r"""
        Compute the v isoparametric gp_circ of the cylinder.

        Parameters
        ----------
        Pos: gp_Ax3
        Radius: float
        V: float

        Returns
        -------
        gp_Circ

        """
        return _ElSLib.elslib_CylinderVIso(*args)

    @staticmethod
    def CylinderValue(*args) -> "gp_Pnt":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        Pos: gp_Ax3
        Radius: float

        Returns
        -------
        gp_Pnt

        """
        return _ElSLib.elslib_CylinderValue(*args)

    @staticmethod
    def D0(*args) -> "void":
        r"""
        For elementary surfaces from the gp package (planes, cones, cylinders, spheres and tori), computes the point p of parameters (u, v).inline.

        Parameters
        ----------
        U: float
        V: float
        Pl: gp_Pln
        P: gp_Pnt

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        C: gp_Cone
        P: gp_Pnt

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        C: gp_Cylinder
        P: gp_Pnt

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        S: gp_Sphere
        P: gp_Pnt

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        T: gp_Torus
        P: gp_Pnt

        Returns
        -------
        None

        """
        return _ElSLib.elslib_D0(*args)

    @staticmethod
    def D1(*args) -> "void":
        r"""
        For elementary surfaces from the gp package (planes, cones, cylinders, spheres and tori), computes: - the point p of parameters (u, v), and - the first derivative vectors vu and vv at this point in the u and v parametric directions respectively.

        Parameters
        ----------
        U: float
        V: float
        Pl: gp_Pln
        P: gp_Pnt
        Vu: gp_Vec
        Vv: gp_Vec

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        C: gp_Cone
        P: gp_Pnt
        Vu: gp_Vec
        Vv: gp_Vec

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        C: gp_Cylinder
        P: gp_Pnt
        Vu: gp_Vec
        Vv: gp_Vec

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        S: gp_Sphere
        P: gp_Pnt
        Vu: gp_Vec
        Vv: gp_Vec

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        T: gp_Torus
        P: gp_Pnt
        Vu: gp_Vec
        Vv: gp_Vec

        Returns
        -------
        None

        """
        return _ElSLib.elslib_D1(*args)

    @staticmethod
    def D2(*args) -> "void":
        r"""
        For elementary surfaces from the gp package (cones, cylinders, spheres and tori), computes: - the point p of parameters (u, v), and - the first derivative vectors vu and vv at this point in the u and v parametric directions respectively, and - the second derivative vectors vuu, vvv and vuv at this point.

        Parameters
        ----------
        U: float
        V: float
        C: gp_Cone
        P: gp_Pnt
        Vu: gp_Vec
        Vv: gp_Vec
        Vuu: gp_Vec
        Vvv: gp_Vec
        Vuv: gp_Vec

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        C: gp_Cylinder
        P: gp_Pnt
        Vu: gp_Vec
        Vv: gp_Vec
        Vuu: gp_Vec
        Vvv: gp_Vec
        Vuv: gp_Vec

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        S: gp_Sphere
        P: gp_Pnt
        Vu: gp_Vec
        Vv: gp_Vec
        Vuu: gp_Vec
        Vvv: gp_Vec
        Vuv: gp_Vec

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        T: gp_Torus
        P: gp_Pnt
        Vu: gp_Vec
        Vv: gp_Vec
        Vuu: gp_Vec
        Vvv: gp_Vec
        Vuv: gp_Vec

        Returns
        -------
        None

        """
        return _ElSLib.elslib_D2(*args)

    @staticmethod
    def D3(*args) -> "void":
        r"""
        For elementary surfaces from the gp package (cones, cylinders, spheres and tori), computes: - the point p of parameters (u,v), and - the first derivative vectors vu and vv at this point in the u and v parametric directions respectively, and - the second derivative vectors vuu, vvv and vuv at this point, and - the third derivative vectors vuuu, vvvv, vuuv and vuvv at this point.

        Parameters
        ----------
        U: float
        V: float
        C: gp_Cone
        P: gp_Pnt
        Vu: gp_Vec
        Vv: gp_Vec
        Vuu: gp_Vec
        Vvv: gp_Vec
        Vuv: gp_Vec
        Vuuu: gp_Vec
        Vvvv: gp_Vec
        Vuuv: gp_Vec
        Vuvv: gp_Vec

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        C: gp_Cylinder
        P: gp_Pnt
        Vu: gp_Vec
        Vv: gp_Vec
        Vuu: gp_Vec
        Vvv: gp_Vec
        Vuv: gp_Vec
        Vuuu: gp_Vec
        Vvvv: gp_Vec
        Vuuv: gp_Vec
        Vuvv: gp_Vec

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        S: gp_Sphere
        P: gp_Pnt
        Vu: gp_Vec
        Vv: gp_Vec
        Vuu: gp_Vec
        Vvv: gp_Vec
        Vuv: gp_Vec
        Vuuu: gp_Vec
        Vvvv: gp_Vec
        Vuuv: gp_Vec
        Vuvv: gp_Vec

        Returns
        -------
        None
        Surface evaluation the following functions compute the point and the derivatives on elementary surfaces defined with their geometric characterisitics. you don't need to create the surface to use these functions. these functions are called by the previous ones. example : a cylinder is defined with its position and its radius.

        Parameters
        ----------
        U: float
        V: float
        T: gp_Torus
        P: gp_Pnt
        Vu: gp_Vec
        Vv: gp_Vec
        Vuu: gp_Vec
        Vvv: gp_Vec
        Vuv: gp_Vec
        Vuuu: gp_Vec
        Vvvv: gp_Vec
        Vuuv: gp_Vec
        Vuvv: gp_Vec

        Returns
        -------
        None

        """
        return _ElSLib.elslib_D3(*args)

    @staticmethod
    def DN(*args) -> "gp_Vec":
        r"""
        For elementary surfaces from the gp package (planes, cones, cylinders, spheres and tori), computes the derivative vector of order nu and nv in the u and v parametric directions respectively, at the point of parameters (u, v).

        Parameters
        ----------
        U: float
        V: float
        Pl: gp_Pln
        Nu: int
        Nv: int

        Returns
        -------
        gp_Vec
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        C: gp_Cone
        Nu: int
        Nv: int

        Returns
        -------
        gp_Vec
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        C: gp_Cylinder
        Nu: int
        Nv: int

        Returns
        -------
        gp_Vec
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        S: gp_Sphere
        Nu: int
        Nv: int

        Returns
        -------
        gp_Vec
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        T: gp_Torus
        Nu: int
        Nv: int

        Returns
        -------
        gp_Vec

        """
        return _ElSLib.elslib_DN(*args)

    @staticmethod
    def Parameters(*args) -> "Standard_Real &, Standard_Real &":
        r"""
        Parametrization p (u, v) = pl.location() + u * pl.xdirection() + v * pl.ydirection().

        Parameters
        ----------
        Pl: gp_Pln
        P: gp_Pnt

        Returns
        -------
        U: float
        V: float
        Parametrization p (u, v) = location + v * zdirection + radius * (cos(u) * xdirection + sin (u) * ydirection).

        Parameters
        ----------
        C: gp_Cylinder
        P: gp_Pnt

        Returns
        -------
        U: float
        V: float
        Parametrization p (u, v) = location + v * zdirection + (radius + v * tan (semiangle)) * (cos(u) * xdirection + sin(u) * ydirection).

        Parameters
        ----------
        C: gp_Cone
        P: gp_Pnt

        Returns
        -------
        U: float
        V: float
        Parametrization p (u, v) = location + radius * cos (v) * (cos (u) * xdirection + sin (u) * ydirection) + radius * sin (v) * zdirection.

        Parameters
        ----------
        S: gp_Sphere
        P: gp_Pnt

        Returns
        -------
        U: float
        V: float
        Parametrization p (u, v) = location + (majorradius + minorradius * cos(u)) * (cos(v) * xdirection - sin(v) * ydirection) + minorradius * sin(u) * zdirection.

        Parameters
        ----------
        T: gp_Torus
        P: gp_Pnt

        Returns
        -------
        U: float
        V: float

        """
        return _ElSLib.elslib_Parameters(*args)

    @staticmethod
    def PlaneD0(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        Pos: gp_Ax3
        P: gp_Pnt

        Returns
        -------
        None

        """
        return _ElSLib.elslib_PlaneD0(*args)

    @staticmethod
    def PlaneD1(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        Pos: gp_Ax3
        P: gp_Pnt
        Vu: gp_Vec
        Vv: gp_Vec

        Returns
        -------
        None

        """
        return _ElSLib.elslib_PlaneD1(*args)

    @staticmethod
    def PlaneDN(*args) -> "gp_Vec":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        Pos: gp_Ax3
        Nu: int
        Nv: int

        Returns
        -------
        gp_Vec

        """
        return _ElSLib.elslib_PlaneDN(*args)

    @staticmethod
    def PlaneParameters(*args) -> "Standard_Real &, Standard_Real &":
        r"""
        Parametrization p (u, v) = pl.location() + u * pl.xdirection() + v * pl.ydirection().

        Parameters
        ----------
        Pos: gp_Ax3
        P: gp_Pnt

        Returns
        -------
        U: float
        V: float

        """
        return _ElSLib.elslib_PlaneParameters(*args)

    @staticmethod
    def PlaneUIso(*args) -> "gp_Lin":
        r"""
        Compute the u isoparametric gp_lin of the plane.

        Parameters
        ----------
        Pos: gp_Ax3
        U: float

        Returns
        -------
        gp_Lin

        """
        return _ElSLib.elslib_PlaneUIso(*args)

    @staticmethod
    def PlaneVIso(*args) -> "gp_Lin":
        r"""
        Compute the v isoparametric gp_lin of the plane.

        Parameters
        ----------
        Pos: gp_Ax3
        V: float

        Returns
        -------
        gp_Lin

        """
        return _ElSLib.elslib_PlaneVIso(*args)

    @staticmethod
    def PlaneValue(*args) -> "gp_Pnt":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        Pos: gp_Ax3

        Returns
        -------
        gp_Pnt

        """
        return _ElSLib.elslib_PlaneValue(*args)

    @staticmethod
    def SphereD0(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        Pos: gp_Ax3
        Radius: float
        P: gp_Pnt

        Returns
        -------
        None

        """
        return _ElSLib.elslib_SphereD0(*args)

    @staticmethod
    def SphereD1(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        Pos: gp_Ax3
        Radius: float
        P: gp_Pnt
        Vu: gp_Vec
        Vv: gp_Vec

        Returns
        -------
        None

        """
        return _ElSLib.elslib_SphereD1(*args)

    @staticmethod
    def SphereD2(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        Pos: gp_Ax3
        Radius: float
        P: gp_Pnt
        Vu: gp_Vec
        Vv: gp_Vec
        Vuu: gp_Vec
        Vvv: gp_Vec
        Vuv: gp_Vec

        Returns
        -------
        None

        """
        return _ElSLib.elslib_SphereD2(*args)

    @staticmethod
    def SphereD3(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        Pos: gp_Ax3
        Radius: float
        P: gp_Pnt
        Vu: gp_Vec
        Vv: gp_Vec
        Vuu: gp_Vec
        Vvv: gp_Vec
        Vuv: gp_Vec
        Vuuu: gp_Vec
        Vvvv: gp_Vec
        Vuuv: gp_Vec
        Vuvv: gp_Vec

        Returns
        -------
        None

        """
        return _ElSLib.elslib_SphereD3(*args)

    @staticmethod
    def SphereDN(*args) -> "gp_Vec":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        Pos: gp_Ax3
        Radius: float
        Nu: int
        Nv: int

        Returns
        -------
        gp_Vec

        """
        return _ElSLib.elslib_SphereDN(*args)

    @staticmethod
    def SphereParameters(*args) -> "Standard_Real &, Standard_Real &":
        r"""
        Parametrization p (u, v) = location + radius * cos (v) * (cos (u) * xdirection + sin (u) * ydirection) + radius * sin (v) * zdirection.

        Parameters
        ----------
        Pos: gp_Ax3
        Radius: float
        P: gp_Pnt

        Returns
        -------
        U: float
        V: float

        """
        return _ElSLib.elslib_SphereParameters(*args)

    @staticmethod
    def SphereUIso(*args) -> "gp_Circ":
        r"""
        Compute the u isoparametric gp_circ of the sphere, (the meridian is not trimmed).

        Parameters
        ----------
        Pos: gp_Ax3
        Radius: float
        U: float

        Returns
        -------
        gp_Circ

        """
        return _ElSLib.elslib_SphereUIso(*args)

    @staticmethod
    def SphereVIso(*args) -> "gp_Circ":
        r"""
        Compute the v isoparametric gp_circ of the sphere, (the meridian is not trimmed).

        Parameters
        ----------
        Pos: gp_Ax3
        Radius: float
        V: float

        Returns
        -------
        gp_Circ

        """
        return _ElSLib.elslib_SphereVIso(*args)

    @staticmethod
    def SphereValue(*args) -> "gp_Pnt":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        Pos: gp_Ax3
        Radius: float

        Returns
        -------
        gp_Pnt

        """
        return _ElSLib.elslib_SphereValue(*args)

    @staticmethod
    def TorusD0(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        Pos: gp_Ax3
        MajorRadius: float
        MinorRadius: float
        P: gp_Pnt

        Returns
        -------
        None

        """
        return _ElSLib.elslib_TorusD0(*args)

    @staticmethod
    def TorusD1(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        Pos: gp_Ax3
        MajorRadius: float
        MinorRadius: float
        P: gp_Pnt
        Vu: gp_Vec
        Vv: gp_Vec

        Returns
        -------
        None

        """
        return _ElSLib.elslib_TorusD1(*args)

    @staticmethod
    def TorusD2(*args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        Pos: gp_Ax3
        MajorRadius: float
        MinorRadius: float
        P: gp_Pnt
        Vu: gp_Vec
        Vv: gp_Vec
        Vuu: gp_Vec
        Vvv: gp_Vec
        Vuv: gp_Vec

        Returns
        -------
        None

        """
        return _ElSLib.elslib_TorusD2(*args)

    @staticmethod
    def TorusD3(*args) -> "void":
        r"""
        The following functions compute the parametric values corresponding to a given point on a elementary surface. the point should be on the surface.

        Parameters
        ----------
        U: float
        V: float
        Pos: gp_Ax3
        MajorRadius: float
        MinorRadius: float
        P: gp_Pnt
        Vu: gp_Vec
        Vv: gp_Vec
        Vuu: gp_Vec
        Vvv: gp_Vec
        Vuv: gp_Vec
        Vuuu: gp_Vec
        Vvvv: gp_Vec
        Vuuv: gp_Vec
        Vuvv: gp_Vec

        Returns
        -------
        None

        """
        return _ElSLib.elslib_TorusD3(*args)

    @staticmethod
    def TorusDN(*args) -> "gp_Vec":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        Pos: gp_Ax3
        MajorRadius: float
        MinorRadius: float
        Nu: int
        Nv: int

        Returns
        -------
        gp_Vec

        """
        return _ElSLib.elslib_TorusDN(*args)

    @staticmethod
    def TorusParameters(*args) -> "Standard_Real &, Standard_Real &":
        r"""
        Parametrization p (u, v) = location + (majorradius + minorradius * cos(u)) * (cos(v) * xdirection - sin(v) * ydirection) + minorradius * sin(u) * zdirection.

        Parameters
        ----------
        Pos: gp_Ax3
        MajorRadius: float
        MinorRadius: float
        P: gp_Pnt

        Returns
        -------
        U: float
        V: float

        """
        return _ElSLib.elslib_TorusParameters(*args)

    @staticmethod
    def TorusUIso(*args) -> "gp_Circ":
        r"""
        Compute the u isoparametric gp_circ of the torus.

        Parameters
        ----------
        Pos: gp_Ax3
        MajorRadius: float
        MinorRadius: float
        U: float

        Returns
        -------
        gp_Circ

        """
        return _ElSLib.elslib_TorusUIso(*args)

    @staticmethod
    def TorusVIso(*args) -> "gp_Circ":
        r"""
        Compute the v isoparametric gp_circ of the torus.

        Parameters
        ----------
        Pos: gp_Ax3
        MajorRadius: float
        MinorRadius: float
        V: float

        Returns
        -------
        gp_Circ

        """
        return _ElSLib.elslib_TorusVIso(*args)

    @staticmethod
    def TorusValue(*args) -> "gp_Pnt":
        r"""
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        Pos: gp_Ax3
        MajorRadius: float
        MinorRadius: float

        Returns
        -------
        gp_Pnt

        """
        return _ElSLib.elslib_TorusValue(*args)

    @staticmethod
    def Value(*args) -> "gp_Pnt":
        r"""
        For elementary surfaces from the gp package (planes, cones, cylinders, spheres and tori), computes the point of parameters (u, v).

        Parameters
        ----------
        U: float
        V: float
        Pl: gp_Pln

        Returns
        -------
        gp_Pnt
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        C: gp_Cone

        Returns
        -------
        gp_Pnt
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        C: gp_Cylinder

        Returns
        -------
        gp_Pnt
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        S: gp_Sphere

        Returns
        -------
        gp_Pnt
        No available documentation.

        Parameters
        ----------
        U: float
        V: float
        T: gp_Torus

        Returns
        -------
        gp_Pnt

        """
        return _ElSLib.elslib_Value(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _ElSLib.elslib_swiginit(self, _ElSLib.new_elslib())
    __swig_destroy__ = _ElSLib.delete_elslib

# Register elslib in _ElSLib:
_ElSLib.elslib_swigregister(elslib)

def elslib_ConeD0(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    Pos: gp_Ax3
    Radius: float
    SAngle: float
    P: gp_Pnt

    Returns
    -------
    None

    """
    return _ElSLib.elslib_ConeD0(*args)

def elslib_ConeD1(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    Pos: gp_Ax3
    Radius: float
    SAngle: float
    P: gp_Pnt
    Vu: gp_Vec
    Vv: gp_Vec

    Returns
    -------
    None

    """
    return _ElSLib.elslib_ConeD1(*args)

def elslib_ConeD2(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    Pos: gp_Ax3
    Radius: float
    SAngle: float
    P: gp_Pnt
    Vu: gp_Vec
    Vv: gp_Vec
    Vuu: gp_Vec
    Vvv: gp_Vec
    Vuv: gp_Vec

    Returns
    -------
    None

    """
    return _ElSLib.elslib_ConeD2(*args)

def elslib_ConeD3(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    Pos: gp_Ax3
    Radius: float
    SAngle: float
    P: gp_Pnt
    Vu: gp_Vec
    Vv: gp_Vec
    Vuu: gp_Vec
    Vvv: gp_Vec
    Vuv: gp_Vec
    Vuuu: gp_Vec
    Vvvv: gp_Vec
    Vuuv: gp_Vec
    Vuvv: gp_Vec

    Returns
    -------
    None

    """
    return _ElSLib.elslib_ConeD3(*args)

def elslib_ConeDN(*args) -> "gp_Vec":
    r"""
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    Pos: gp_Ax3
    Radius: float
    SAngle: float
    Nu: int
    Nv: int

    Returns
    -------
    gp_Vec

    """
    return _ElSLib.elslib_ConeDN(*args)

def elslib_ConeParameters(*args) -> "Standard_Real &, Standard_Real &":
    r"""
    Parametrization p (u, v) = location + v * zdirection + (radius + v * tan (semiangle)) * (cos(u) * xdirection + sin(u) * ydirection).

    Parameters
    ----------
    Pos: gp_Ax3
    Radius: float
    SAngle: float
    P: gp_Pnt

    Returns
    -------
    U: float
    V: float

    """
    return _ElSLib.elslib_ConeParameters(*args)

def elslib_ConeUIso(*args) -> "gp_Lin":
    r"""
    Compute the u isoparametric gp_lin of the cone.

    Parameters
    ----------
    Pos: gp_Ax3
    Radius: float
    SAngle: float
    U: float

    Returns
    -------
    gp_Lin

    """
    return _ElSLib.elslib_ConeUIso(*args)

def elslib_ConeVIso(*args) -> "gp_Circ":
    r"""
    Compute the v isoparametric gp_circ of the cone.

    Parameters
    ----------
    Pos: gp_Ax3
    Radius: float
    SAngle: float
    V: float

    Returns
    -------
    gp_Circ

    """
    return _ElSLib.elslib_ConeVIso(*args)

def elslib_ConeValue(*args) -> "gp_Pnt":
    r"""
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    Pos: gp_Ax3
    Radius: float
    SAngle: float

    Returns
    -------
    gp_Pnt

    """
    return _ElSLib.elslib_ConeValue(*args)

def elslib_CylinderD0(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    Pos: gp_Ax3
    Radius: float
    P: gp_Pnt

    Returns
    -------
    None

    """
    return _ElSLib.elslib_CylinderD0(*args)

def elslib_CylinderD1(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    Pos: gp_Ax3
    Radius: float
    P: gp_Pnt
    Vu: gp_Vec
    Vv: gp_Vec

    Returns
    -------
    None

    """
    return _ElSLib.elslib_CylinderD1(*args)

def elslib_CylinderD2(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    Pos: gp_Ax3
    Radius: float
    P: gp_Pnt
    Vu: gp_Vec
    Vv: gp_Vec
    Vuu: gp_Vec
    Vvv: gp_Vec
    Vuv: gp_Vec

    Returns
    -------
    None

    """
    return _ElSLib.elslib_CylinderD2(*args)

def elslib_CylinderD3(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    Pos: gp_Ax3
    Radius: float
    P: gp_Pnt
    Vu: gp_Vec
    Vv: gp_Vec
    Vuu: gp_Vec
    Vvv: gp_Vec
    Vuv: gp_Vec
    Vuuu: gp_Vec
    Vvvv: gp_Vec
    Vuuv: gp_Vec
    Vuvv: gp_Vec

    Returns
    -------
    None

    """
    return _ElSLib.elslib_CylinderD3(*args)

def elslib_CylinderDN(*args) -> "gp_Vec":
    r"""
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    Pos: gp_Ax3
    Radius: float
    Nu: int
    Nv: int

    Returns
    -------
    gp_Vec

    """
    return _ElSLib.elslib_CylinderDN(*args)

def elslib_CylinderParameters(*args) -> "Standard_Real &, Standard_Real &":
    r"""
    Parametrization p (u, v) = location + v * zdirection + radius * (cos(u) * xdirection + sin (u) * ydirection).

    Parameters
    ----------
    Pos: gp_Ax3
    Radius: float
    P: gp_Pnt

    Returns
    -------
    U: float
    V: float

    """
    return _ElSLib.elslib_CylinderParameters(*args)

def elslib_CylinderUIso(*args) -> "gp_Lin":
    r"""
    Compute the u isoparametric gp_lin of the cylinder.

    Parameters
    ----------
    Pos: gp_Ax3
    Radius: float
    U: float

    Returns
    -------
    gp_Lin

    """
    return _ElSLib.elslib_CylinderUIso(*args)

def elslib_CylinderVIso(*args) -> "gp_Circ":
    r"""
    Compute the v isoparametric gp_circ of the cylinder.

    Parameters
    ----------
    Pos: gp_Ax3
    Radius: float
    V: float

    Returns
    -------
    gp_Circ

    """
    return _ElSLib.elslib_CylinderVIso(*args)

def elslib_CylinderValue(*args) -> "gp_Pnt":
    r"""
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    Pos: gp_Ax3
    Radius: float

    Returns
    -------
    gp_Pnt

    """
    return _ElSLib.elslib_CylinderValue(*args)

def elslib_D0(*args) -> "void":
    r"""
    For elementary surfaces from the gp package (planes, cones, cylinders, spheres and tori), computes the point p of parameters (u, v).inline.

    Parameters
    ----------
    U: float
    V: float
    Pl: gp_Pln
    P: gp_Pnt

    Returns
    -------
    None
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    C: gp_Cone
    P: gp_Pnt

    Returns
    -------
    None
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    C: gp_Cylinder
    P: gp_Pnt

    Returns
    -------
    None
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    S: gp_Sphere
    P: gp_Pnt

    Returns
    -------
    None
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    T: gp_Torus
    P: gp_Pnt

    Returns
    -------
    None

    """
    return _ElSLib.elslib_D0(*args)

def elslib_D1(*args) -> "void":
    r"""
    For elementary surfaces from the gp package (planes, cones, cylinders, spheres and tori), computes: - the point p of parameters (u, v), and - the first derivative vectors vu and vv at this point in the u and v parametric directions respectively.

    Parameters
    ----------
    U: float
    V: float
    Pl: gp_Pln
    P: gp_Pnt
    Vu: gp_Vec
    Vv: gp_Vec

    Returns
    -------
    None
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    C: gp_Cone
    P: gp_Pnt
    Vu: gp_Vec
    Vv: gp_Vec

    Returns
    -------
    None
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    C: gp_Cylinder
    P: gp_Pnt
    Vu: gp_Vec
    Vv: gp_Vec

    Returns
    -------
    None
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    S: gp_Sphere
    P: gp_Pnt
    Vu: gp_Vec
    Vv: gp_Vec

    Returns
    -------
    None
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    T: gp_Torus
    P: gp_Pnt
    Vu: gp_Vec
    Vv: gp_Vec

    Returns
    -------
    None

    """
    return _ElSLib.elslib_D1(*args)

def elslib_D2(*args) -> "void":
    r"""
    For elementary surfaces from the gp package (cones, cylinders, spheres and tori), computes: - the point p of parameters (u, v), and - the first derivative vectors vu and vv at this point in the u and v parametric directions respectively, and - the second derivative vectors vuu, vvv and vuv at this point.

    Parameters
    ----------
    U: float
    V: float
    C: gp_Cone
    P: gp_Pnt
    Vu: gp_Vec
    Vv: gp_Vec
    Vuu: gp_Vec
    Vvv: gp_Vec
    Vuv: gp_Vec

    Returns
    -------
    None
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    C: gp_Cylinder
    P: gp_Pnt
    Vu: gp_Vec
    Vv: gp_Vec
    Vuu: gp_Vec
    Vvv: gp_Vec
    Vuv: gp_Vec

    Returns
    -------
    None
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    S: gp_Sphere
    P: gp_Pnt
    Vu: gp_Vec
    Vv: gp_Vec
    Vuu: gp_Vec
    Vvv: gp_Vec
    Vuv: gp_Vec

    Returns
    -------
    None
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    T: gp_Torus
    P: gp_Pnt
    Vu: gp_Vec
    Vv: gp_Vec
    Vuu: gp_Vec
    Vvv: gp_Vec
    Vuv: gp_Vec

    Returns
    -------
    None

    """
    return _ElSLib.elslib_D2(*args)

def elslib_D3(*args) -> "void":
    r"""
    For elementary surfaces from the gp package (cones, cylinders, spheres and tori), computes: - the point p of parameters (u,v), and - the first derivative vectors vu and vv at this point in the u and v parametric directions respectively, and - the second derivative vectors vuu, vvv and vuv at this point, and - the third derivative vectors vuuu, vvvv, vuuv and vuvv at this point.

    Parameters
    ----------
    U: float
    V: float
    C: gp_Cone
    P: gp_Pnt
    Vu: gp_Vec
    Vv: gp_Vec
    Vuu: gp_Vec
    Vvv: gp_Vec
    Vuv: gp_Vec
    Vuuu: gp_Vec
    Vvvv: gp_Vec
    Vuuv: gp_Vec
    Vuvv: gp_Vec

    Returns
    -------
    None
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    C: gp_Cylinder
    P: gp_Pnt
    Vu: gp_Vec
    Vv: gp_Vec
    Vuu: gp_Vec
    Vvv: gp_Vec
    Vuv: gp_Vec
    Vuuu: gp_Vec
    Vvvv: gp_Vec
    Vuuv: gp_Vec
    Vuvv: gp_Vec

    Returns
    -------
    None
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    S: gp_Sphere
    P: gp_Pnt
    Vu: gp_Vec
    Vv: gp_Vec
    Vuu: gp_Vec
    Vvv: gp_Vec
    Vuv: gp_Vec
    Vuuu: gp_Vec
    Vvvv: gp_Vec
    Vuuv: gp_Vec
    Vuvv: gp_Vec

    Returns
    -------
    None
    Surface evaluation the following functions compute the point and the derivatives on elementary surfaces defined with their geometric characterisitics. you don't need to create the surface to use these functions. these functions are called by the previous ones. example : a cylinder is defined with its position and its radius.

    Parameters
    ----------
    U: float
    V: float
    T: gp_Torus
    P: gp_Pnt
    Vu: gp_Vec
    Vv: gp_Vec
    Vuu: gp_Vec
    Vvv: gp_Vec
    Vuv: gp_Vec
    Vuuu: gp_Vec
    Vvvv: gp_Vec
    Vuuv: gp_Vec
    Vuvv: gp_Vec

    Returns
    -------
    None

    """
    return _ElSLib.elslib_D3(*args)

def elslib_DN(*args) -> "gp_Vec":
    r"""
    For elementary surfaces from the gp package (planes, cones, cylinders, spheres and tori), computes the derivative vector of order nu and nv in the u and v parametric directions respectively, at the point of parameters (u, v).

    Parameters
    ----------
    U: float
    V: float
    Pl: gp_Pln
    Nu: int
    Nv: int

    Returns
    -------
    gp_Vec
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    C: gp_Cone
    Nu: int
    Nv: int

    Returns
    -------
    gp_Vec
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    C: gp_Cylinder
    Nu: int
    Nv: int

    Returns
    -------
    gp_Vec
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    S: gp_Sphere
    Nu: int
    Nv: int

    Returns
    -------
    gp_Vec
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    T: gp_Torus
    Nu: int
    Nv: int

    Returns
    -------
    gp_Vec

    """
    return _ElSLib.elslib_DN(*args)

def elslib_Parameters(*args) -> "Standard_Real &, Standard_Real &":
    r"""
    Parametrization p (u, v) = pl.location() + u * pl.xdirection() + v * pl.ydirection().

    Parameters
    ----------
    Pl: gp_Pln
    P: gp_Pnt

    Returns
    -------
    U: float
    V: float
    Parametrization p (u, v) = location + v * zdirection + radius * (cos(u) * xdirection + sin (u) * ydirection).

    Parameters
    ----------
    C: gp_Cylinder
    P: gp_Pnt

    Returns
    -------
    U: float
    V: float
    Parametrization p (u, v) = location + v * zdirection + (radius + v * tan (semiangle)) * (cos(u) * xdirection + sin(u) * ydirection).

    Parameters
    ----------
    C: gp_Cone
    P: gp_Pnt

    Returns
    -------
    U: float
    V: float
    Parametrization p (u, v) = location + radius * cos (v) * (cos (u) * xdirection + sin (u) * ydirection) + radius * sin (v) * zdirection.

    Parameters
    ----------
    S: gp_Sphere
    P: gp_Pnt

    Returns
    -------
    U: float
    V: float
    Parametrization p (u, v) = location + (majorradius + minorradius * cos(u)) * (cos(v) * xdirection - sin(v) * ydirection) + minorradius * sin(u) * zdirection.

    Parameters
    ----------
    T: gp_Torus
    P: gp_Pnt

    Returns
    -------
    U: float
    V: float

    """
    return _ElSLib.elslib_Parameters(*args)

def elslib_PlaneD0(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    Pos: gp_Ax3
    P: gp_Pnt

    Returns
    -------
    None

    """
    return _ElSLib.elslib_PlaneD0(*args)

def elslib_PlaneD1(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    Pos: gp_Ax3
    P: gp_Pnt
    Vu: gp_Vec
    Vv: gp_Vec

    Returns
    -------
    None

    """
    return _ElSLib.elslib_PlaneD1(*args)

def elslib_PlaneDN(*args) -> "gp_Vec":
    r"""
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    Pos: gp_Ax3
    Nu: int
    Nv: int

    Returns
    -------
    gp_Vec

    """
    return _ElSLib.elslib_PlaneDN(*args)

def elslib_PlaneParameters(*args) -> "Standard_Real &, Standard_Real &":
    r"""
    Parametrization p (u, v) = pl.location() + u * pl.xdirection() + v * pl.ydirection().

    Parameters
    ----------
    Pos: gp_Ax3
    P: gp_Pnt

    Returns
    -------
    U: float
    V: float

    """
    return _ElSLib.elslib_PlaneParameters(*args)

def elslib_PlaneUIso(*args) -> "gp_Lin":
    r"""
    Compute the u isoparametric gp_lin of the plane.

    Parameters
    ----------
    Pos: gp_Ax3
    U: float

    Returns
    -------
    gp_Lin

    """
    return _ElSLib.elslib_PlaneUIso(*args)

def elslib_PlaneVIso(*args) -> "gp_Lin":
    r"""
    Compute the v isoparametric gp_lin of the plane.

    Parameters
    ----------
    Pos: gp_Ax3
    V: float

    Returns
    -------
    gp_Lin

    """
    return _ElSLib.elslib_PlaneVIso(*args)

def elslib_PlaneValue(*args) -> "gp_Pnt":
    r"""
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    Pos: gp_Ax3

    Returns
    -------
    gp_Pnt

    """
    return _ElSLib.elslib_PlaneValue(*args)

def elslib_SphereD0(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    Pos: gp_Ax3
    Radius: float
    P: gp_Pnt

    Returns
    -------
    None

    """
    return _ElSLib.elslib_SphereD0(*args)

def elslib_SphereD1(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    Pos: gp_Ax3
    Radius: float
    P: gp_Pnt
    Vu: gp_Vec
    Vv: gp_Vec

    Returns
    -------
    None

    """
    return _ElSLib.elslib_SphereD1(*args)

def elslib_SphereD2(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    Pos: gp_Ax3
    Radius: float
    P: gp_Pnt
    Vu: gp_Vec
    Vv: gp_Vec
    Vuu: gp_Vec
    Vvv: gp_Vec
    Vuv: gp_Vec

    Returns
    -------
    None

    """
    return _ElSLib.elslib_SphereD2(*args)

def elslib_SphereD3(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    Pos: gp_Ax3
    Radius: float
    P: gp_Pnt
    Vu: gp_Vec
    Vv: gp_Vec
    Vuu: gp_Vec
    Vvv: gp_Vec
    Vuv: gp_Vec
    Vuuu: gp_Vec
    Vvvv: gp_Vec
    Vuuv: gp_Vec
    Vuvv: gp_Vec

    Returns
    -------
    None

    """
    return _ElSLib.elslib_SphereD3(*args)

def elslib_SphereDN(*args) -> "gp_Vec":
    r"""
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    Pos: gp_Ax3
    Radius: float
    Nu: int
    Nv: int

    Returns
    -------
    gp_Vec

    """
    return _ElSLib.elslib_SphereDN(*args)

def elslib_SphereParameters(*args) -> "Standard_Real &, Standard_Real &":
    r"""
    Parametrization p (u, v) = location + radius * cos (v) * (cos (u) * xdirection + sin (u) * ydirection) + radius * sin (v) * zdirection.

    Parameters
    ----------
    Pos: gp_Ax3
    Radius: float
    P: gp_Pnt

    Returns
    -------
    U: float
    V: float

    """
    return _ElSLib.elslib_SphereParameters(*args)

def elslib_SphereUIso(*args) -> "gp_Circ":
    r"""
    Compute the u isoparametric gp_circ of the sphere, (the meridian is not trimmed).

    Parameters
    ----------
    Pos: gp_Ax3
    Radius: float
    U: float

    Returns
    -------
    gp_Circ

    """
    return _ElSLib.elslib_SphereUIso(*args)

def elslib_SphereVIso(*args) -> "gp_Circ":
    r"""
    Compute the v isoparametric gp_circ of the sphere, (the meridian is not trimmed).

    Parameters
    ----------
    Pos: gp_Ax3
    Radius: float
    V: float

    Returns
    -------
    gp_Circ

    """
    return _ElSLib.elslib_SphereVIso(*args)

def elslib_SphereValue(*args) -> "gp_Pnt":
    r"""
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    Pos: gp_Ax3
    Radius: float

    Returns
    -------
    gp_Pnt

    """
    return _ElSLib.elslib_SphereValue(*args)

def elslib_TorusD0(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    Pos: gp_Ax3
    MajorRadius: float
    MinorRadius: float
    P: gp_Pnt

    Returns
    -------
    None

    """
    return _ElSLib.elslib_TorusD0(*args)

def elslib_TorusD1(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    Pos: gp_Ax3
    MajorRadius: float
    MinorRadius: float
    P: gp_Pnt
    Vu: gp_Vec
    Vv: gp_Vec

    Returns
    -------
    None

    """
    return _ElSLib.elslib_TorusD1(*args)

def elslib_TorusD2(*args) -> "void":
    r"""
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    Pos: gp_Ax3
    MajorRadius: float
    MinorRadius: float
    P: gp_Pnt
    Vu: gp_Vec
    Vv: gp_Vec
    Vuu: gp_Vec
    Vvv: gp_Vec
    Vuv: gp_Vec

    Returns
    -------
    None

    """
    return _ElSLib.elslib_TorusD2(*args)

def elslib_TorusD3(*args) -> "void":
    r"""
    The following functions compute the parametric values corresponding to a given point on a elementary surface. the point should be on the surface.

    Parameters
    ----------
    U: float
    V: float
    Pos: gp_Ax3
    MajorRadius: float
    MinorRadius: float
    P: gp_Pnt
    Vu: gp_Vec
    Vv: gp_Vec
    Vuu: gp_Vec
    Vvv: gp_Vec
    Vuv: gp_Vec
    Vuuu: gp_Vec
    Vvvv: gp_Vec
    Vuuv: gp_Vec
    Vuvv: gp_Vec

    Returns
    -------
    None

    """
    return _ElSLib.elslib_TorusD3(*args)

def elslib_TorusDN(*args) -> "gp_Vec":
    r"""
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    Pos: gp_Ax3
    MajorRadius: float
    MinorRadius: float
    Nu: int
    Nv: int

    Returns
    -------
    gp_Vec

    """
    return _ElSLib.elslib_TorusDN(*args)

def elslib_TorusParameters(*args) -> "Standard_Real &, Standard_Real &":
    r"""
    Parametrization p (u, v) = location + (majorradius + minorradius * cos(u)) * (cos(v) * xdirection - sin(v) * ydirection) + minorradius * sin(u) * zdirection.

    Parameters
    ----------
    Pos: gp_Ax3
    MajorRadius: float
    MinorRadius: float
    P: gp_Pnt

    Returns
    -------
    U: float
    V: float

    """
    return _ElSLib.elslib_TorusParameters(*args)

def elslib_TorusUIso(*args) -> "gp_Circ":
    r"""
    Compute the u isoparametric gp_circ of the torus.

    Parameters
    ----------
    Pos: gp_Ax3
    MajorRadius: float
    MinorRadius: float
    U: float

    Returns
    -------
    gp_Circ

    """
    return _ElSLib.elslib_TorusUIso(*args)

def elslib_TorusVIso(*args) -> "gp_Circ":
    r"""
    Compute the v isoparametric gp_circ of the torus.

    Parameters
    ----------
    Pos: gp_Ax3
    MajorRadius: float
    MinorRadius: float
    V: float

    Returns
    -------
    gp_Circ

    """
    return _ElSLib.elslib_TorusVIso(*args)

def elslib_TorusValue(*args) -> "gp_Pnt":
    r"""
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    Pos: gp_Ax3
    MajorRadius: float
    MinorRadius: float

    Returns
    -------
    gp_Pnt

    """
    return _ElSLib.elslib_TorusValue(*args)

def elslib_Value(*args) -> "gp_Pnt":
    r"""
    For elementary surfaces from the gp package (planes, cones, cylinders, spheres and tori), computes the point of parameters (u, v).

    Parameters
    ----------
    U: float
    V: float
    Pl: gp_Pln

    Returns
    -------
    gp_Pnt
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    C: gp_Cone

    Returns
    -------
    gp_Pnt
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    C: gp_Cylinder

    Returns
    -------
    gp_Pnt
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    S: gp_Sphere

    Returns
    -------
    gp_Pnt
    No available documentation.

    Parameters
    ----------
    U: float
    V: float
    T: gp_Torus

    Returns
    -------
    gp_Pnt

    """
    return _ElSLib.elslib_Value(*args)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TopoDS import *
from OCC.Core.TopTools import *
from OCC.Core.Geom import *
from OCC.Core.Geom2d import *
from OCC.Core.Adaptor3d import *
from OCC.Core.gp import *
from OCC.Core.GeomAbs import *
from OCC.Core.TColStd import *


class BiTgte_ContactType(IntEnum):
	BiTgte_FaceFace: int = ...
	BiTgte_FaceEdge: int = ...
	BiTgte_FaceVertex: int = ...
	BiTgte_EdgeEdge: int = ...
	BiTgte_EdgeVertex: int = ...
	BiTgte_VertexVertex: int = ...
BiTgte_FaceFace = BiTgte_ContactType.BiTgte_FaceFace
BiTgte_FaceEdge = BiTgte_ContactType.BiTgte_FaceEdge
BiTgte_FaceVertex = BiTgte_ContactType.BiTgte_FaceVertex
BiTgte_EdgeEdge = BiTgte_ContactType.BiTgte_EdgeEdge
BiTgte_EdgeVertex = BiTgte_ContactType.BiTgte_EdgeVertex
BiTgte_VertexVertex = BiTgte_ContactType.BiTgte_VertexVertex

class BiTgte_Blend:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, S: TopoDS_Shape, Radius: float, Tol: float, NUBS: bool) -> None: ...
	def CenterLines(self, LC: TopTools_ListOfShape) -> None: ...
	def Clear(self) -> None: ...
	def ComputeCenters(self) -> None: ...
	def ContactType(self, Index: int) -> BiTgte_ContactType: ...
	def CurveOnShape1(self, Index: int) -> Geom_Curve: ...
	def CurveOnShape2(self, Index: int) -> Geom_Curve: ...
	@overload
	def Face(self, Index: int) -> TopoDS_Face: ...
	@overload
	def Face(self, CenterLine: TopoDS_Shape) -> TopoDS_Face: ...
	def IndicesOfBranche(self, Index: int) -> Tuple[int, int]: ...
	def Init(self, S: TopoDS_Shape, Radius: float, Tol: float, NUBS: bool) -> None: ...
	def IsDone(self) -> bool: ...
	def NbBranches(self) -> int: ...
	def NbSurfaces(self) -> int: ...
	def PCurve1OnFillet(self, Index: int) -> Geom2d_Curve: ...
	def PCurve2OnFillet(self, Index: int) -> Geom2d_Curve: ...
	def PCurveOnFace1(self, Index: int) -> Geom2d_Curve: ...
	def PCurveOnFace2(self, Index: int) -> Geom2d_Curve: ...
	def Perform(self, BuildShape: Optional[bool] = True) -> None: ...
	def SetEdge(self, Edge: TopoDS_Edge) -> None: ...
	def SetFaces(self, F1: TopoDS_Face, F2: TopoDS_Face) -> None: ...
	def SetStoppingFace(self, Face: TopoDS_Face) -> None: ...
	def Shape(self) -> TopoDS_Shape: ...
	def SupportShape1(self, Index: int) -> TopoDS_Shape: ...
	def SupportShape2(self, Index: int) -> TopoDS_Shape: ...
	@overload
	def Surface(self, Index: int) -> Geom_Surface: ...
	@overload
	def Surface(self, CenterLine: TopoDS_Shape) -> Geom_Surface: ...

class BiTgte_CurveOnEdge(Adaptor3d_Curve):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, EonF: TopoDS_Edge, Edge: TopoDS_Edge) -> None: ...
	def BSpline(self) -> Geom_BSplineCurve: ...
	def Bezier(self) -> Geom_BezierCurve: ...
	def Circle(self) -> gp_Circ: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def D0(self, U: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, P: gp_Pnt, V: gp_Vec) -> None: ...
	def D2(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	def D3(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec: ...
	def Degree(self) -> int: ...
	def Ellipse(self) -> gp_Elips: ...
	def FirstParameter(self) -> float: ...
	def GetType(self) -> GeomAbs_CurveType: ...
	def Hyperbola(self) -> gp_Hypr: ...
	def Init(self, EonF: TopoDS_Edge, Edge: TopoDS_Edge) -> None: ...
	def Intervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def IsRational(self) -> bool: ...
	def LastParameter(self) -> float: ...
	def Line(self) -> gp_Lin: ...
	def NbIntervals(self, S: GeomAbs_Shape) -> int: ...
	def NbKnots(self) -> int: ...
	def NbPoles(self) -> int: ...
	def Parabola(self) -> gp_Parab: ...
	def Period(self) -> float: ...
	def Resolution(self, R3d: float) -> float: ...
	def Trim(self, First: float, Last: float, Tol: float) -> Adaptor3d_HCurve: ...
	def Value(self, U: float) -> gp_Pnt: ...

class BiTgte_CurveOnVertex(Adaptor3d_Curve):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, EonF: TopoDS_Edge, V: TopoDS_Vertex) -> None: ...
	def BSpline(self) -> Geom_BSplineCurve: ...
	def Bezier(self) -> Geom_BezierCurve: ...
	def Circle(self) -> gp_Circ: ...
	def Continuity(self) -> GeomAbs_Shape: ...
	def D0(self, U: float, P: gp_Pnt) -> None: ...
	def D1(self, U: float, P: gp_Pnt, V: gp_Vec) -> None: ...
	def D2(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	def D3(self, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	def DN(self, U: float, N: int) -> gp_Vec: ...
	def Degree(self) -> int: ...
	def Ellipse(self) -> gp_Elips: ...
	def FirstParameter(self) -> float: ...
	def GetType(self) -> GeomAbs_CurveType: ...
	def Hyperbola(self) -> gp_Hypr: ...
	def Init(self, EonF: TopoDS_Edge, V: TopoDS_Vertex) -> None: ...
	def Intervals(self, T: TColStd_Array1OfReal, S: GeomAbs_Shape) -> None: ...
	def IsClosed(self) -> bool: ...
	def IsPeriodic(self) -> bool: ...
	def IsRational(self) -> bool: ...
	def LastParameter(self) -> float: ...
	def Line(self) -> gp_Lin: ...
	def NbIntervals(self, S: GeomAbs_Shape) -> int: ...
	def NbKnots(self) -> int: ...
	def NbPoles(self) -> int: ...
	def Parabola(self) -> gp_Parab: ...
	def Period(self) -> float: ...
	def Resolution(self, R3d: float) -> float: ...
	def Trim(self, First: float, Last: float, Tol: float) -> Adaptor3d_HCurve: ...
	def Value(self, U: float) -> gp_Pnt: ...

class BiTgte_HCurveOnEdge(Adaptor3d_HCurve):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C: BiTgte_CurveOnEdge) -> None: ...
	def ChangeCurve(self) -> BiTgte_CurveOnEdge: ...
	def Curve(self) -> Adaptor3d_Curve: ...
	def GetCurve(self) -> Adaptor3d_Curve: ...
	def Set(self, C: BiTgte_CurveOnEdge) -> None: ...

class BiTgte_HCurveOnVertex(Adaptor3d_HCurve):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, C: BiTgte_CurveOnVertex) -> None: ...
	def ChangeCurve(self) -> BiTgte_CurveOnVertex: ...
	def Curve(self) -> Adaptor3d_Curve: ...
	def GetCurve(self) -> Adaptor3d_Curve: ...
	def Set(self, C: BiTgte_CurveOnVertex) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes




# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
Geom2dAPI module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_geom2dapi.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _Geom2dAPI
else:
    import _Geom2dAPI

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _Geom2dAPI.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _Geom2dAPI.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _Geom2dAPI.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _Geom2dAPI.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _Geom2dAPI.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _Geom2dAPI.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _Geom2dAPI.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _Geom2dAPI.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _Geom2dAPI.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _Geom2dAPI.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _Geom2dAPI.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _Geom2dAPI.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _Geom2dAPI.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _Geom2dAPI.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _Geom2dAPI.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _Geom2dAPI.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _Geom2dAPI.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _Geom2dAPI:
_Geom2dAPI.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _Geom2dAPI.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.Geom2d
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.Extrema
import OCC.Core.math
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.Adaptor3d
import OCC.Core.Geom
import OCC.Core.TopAbs
import OCC.Core.Adaptor2d
import OCC.Core.GeomAdaptor
import OCC.Core.Geom2dInt
import OCC.Core.IntRes2d
import OCC.Core.IntCurve
import OCC.Core.Intf
import OCC.Core.Bnd
import OCC.Core.BVH
import OCC.Core.Approx
import OCC.Core.AppCont
import OCC.Core.AppParCurves

from enum import IntEnum
from OCC.Core.Exception import *



class Geom2dAPI_ExtremaCurveCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Computes the extrema between - the portion of the curve c1 limited by the two points of parameter (u1min,u1max), and - the portion of the curve c2 limited by the two points of parameter (u2min,u2max). warning use the function nbextrema to obtain the number of solutions. if this algorithm fails, nbextrema returns 0.

        Parameters
        ----------
        C1: Geom2d_Curve
        C2: Geom2d_Curve
        U1min: float
        U1max: float
        U2min: float
        U2max: float

        Returns
        -------
        None

        """
        _Geom2dAPI.Geom2dAPI_ExtremaCurveCurve_swiginit(self, _Geom2dAPI.new_Geom2dAPI_ExtremaCurveCurve(*args))

    def Distance(self, *args) -> "Standard_Real":
        r"""
        Computes the distance between the end points of the extremum of index index computed by this algorithm. exceptions standard_outofrange if index is not in the range [ 1,nbextrema ], where nbextrema is the number of extrema computed by this algorithm.

        Parameters
        ----------
        Index: int

        Returns
        -------
        float

        """
        return _Geom2dAPI.Geom2dAPI_ExtremaCurveCurve_Distance(self, *args)

    def Extrema(self, *args) -> "Extrema_ExtCC2d const &":
        r"""
        No available documentation.

        Returns
        -------
        Extrema_ExtCC2d

        """
        return _Geom2dAPI.Geom2dAPI_ExtremaCurveCurve_Extrema(self, *args)

    def LowerDistance(self, *args) -> "Standard_Real":
        r"""
        Computes the distance between the end points of the shortest extremum computed by this algorithm. exceptions - stdfail_notdone if this algorithm fails.

        Returns
        -------
        float

        """
        return _Geom2dAPI.Geom2dAPI_ExtremaCurveCurve_LowerDistance(self, *args)

    def LowerDistanceParameters(self, *args) -> "void":
        r"""
        Returns the parameters u1 of the point on the first curve and u2 of the point on the second curve, which are the ends of the shortest extremum computed by this algorithm. exceptions stdfail_notdone if this algorithm fails.

        Parameters
        ----------

        Returns
        -------
        U1: float
        U2: float

        """
        return _Geom2dAPI.Geom2dAPI_ExtremaCurveCurve_LowerDistanceParameters(self, *args)

    def NbExtrema(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of extrema computed by this algorithm. note: if this algorithm fails, nbextrema returns 0.

        Returns
        -------
        int

        """
        return _Geom2dAPI.Geom2dAPI_ExtremaCurveCurve_NbExtrema(self, *args)

    def NearestPoints(self, *args) -> "void":
        r"""
        Returns the points p1 on the first curve and p2 on the second curve, which are the ends of the shortest extremum computed by this algorithm. exceptions stdfail_notdone if this algorithm fails.

        Parameters
        ----------
        P1: gp_Pnt2d
        P2: gp_Pnt2d

        Returns
        -------
        None

        """
        return _Geom2dAPI.Geom2dAPI_ExtremaCurveCurve_NearestPoints(self, *args)

    def Parameters(self, *args) -> "void":
        r"""
        Returns the parameters u1 of the point on the first curve and u2 of the point on the second curve, which are the ends of the extremum of index index computed by this algorithm. exceptions standard_outofrange if index is not in the range [ 1,nbextrema ], where nbextrema is the number of extrema computed by this algorithm.

        Parameters
        ----------
        Index: int

        Returns
        -------
        U1: float
        U2: float

        """
        return _Geom2dAPI.Geom2dAPI_ExtremaCurveCurve_Parameters(self, *args)

    def Points(self, *args) -> "void":
        r"""
        Returns the points p1 on the first curve and p2 on the second curve, which are the ends of the extremum of index index computed by this algorithm. exceptions standard_outofrange if index is not in the range [ 1,nbextrema ], where nbextrema is the number of extrema computed by this algorithm.

        Parameters
        ----------
        Index: int
        P1: gp_Pnt2d
        P2: gp_Pnt2d

        Returns
        -------
        None

        """
        return _Geom2dAPI.Geom2dAPI_ExtremaCurveCurve_Points(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Geom2dAPI.delete_Geom2dAPI_ExtremaCurveCurve

# Register Geom2dAPI_ExtremaCurveCurve in _Geom2dAPI:
_Geom2dAPI.Geom2dAPI_ExtremaCurveCurve_swigregister(Geom2dAPI_ExtremaCurveCurve)

class Geom2dAPI_InterCurveCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Create an empty intersector. use the function init for further initialization of the intersection algorithm by curves or curve.

        Returns
        -------
        None
        Creates an object and computes the intersections between the curves c1 and c2.

        Parameters
        ----------
        C1: Geom2d_Curve
        C2: Geom2d_Curve
        Tol: float,optional
        	default value is 1.0e-6

        Returns
        -------
        None
        Creates an object and computes self-intersections of the curve c1. tolerance value tol, defaulted to 1.0e-6, defines the precision of computing the intersection points. in case of a tangential intersection, tol also defines the size of intersection segments (limited portions of the curves) where the distance between all points from two curves (or a curve in case of self-intersection) is less than tol. warning use functions nbpoints and nbsegments to obtain the number of solutions. if the algorithm finds no intersections nbpoints and nbsegments return 0.

        Parameters
        ----------
        C1: Geom2d_Curve
        Tol: float,optional
        	default value is 1.0e-6

        Returns
        -------
        None

        """
        _Geom2dAPI.Geom2dAPI_InterCurveCurve_swiginit(self, _Geom2dAPI.new_Geom2dAPI_InterCurveCurve(*args))

    def Init(self, *args) -> "void":
        r"""
        Initializes an algorithm with the given arguments and computes the intersections between the curves c1. and c2.

        Parameters
        ----------
        C1: Geom2d_Curve
        C2: Geom2d_Curve
        Tol: float,optional
        	default value is 1.0e-6

        Returns
        -------
        None
        Initializes an algorithm with the given arguments and computes the self-intersections of the curve c1. tolerance value tol, defaulted to 1.0e-6, defines the precision of computing the intersection points. in case of a tangential intersection, tol also defines the size of intersection segments (limited portions of the curves) where the distance between all points from two curves (or a curve in case of self-intersection) is less than tol. warning use functions nbpoints and nbsegments to obtain the number of solutions. if the algorithm finds no intersections nbpoints and nbsegments return 0.

        Parameters
        ----------
        C1: Geom2d_Curve
        Tol: float,optional
        	default value is 1.0e-6

        Returns
        -------
        None

        """
        return _Geom2dAPI.Geom2dAPI_InterCurveCurve_Init(self, *args)

    def Intersector(self, *args) -> "Geom2dInt_GInter const &":
        r"""
        Return the algorithmic object from intersection.

        Returns
        -------
        Geom2dInt_GInter

        """
        return _Geom2dAPI.Geom2dAPI_InterCurveCurve_Intersector(self, *args)

    def NbPoints(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of intersection-points in case of cross intersections. nbpoints returns 0 if no intersections were found.

        Returns
        -------
        int

        """
        return _Geom2dAPI.Geom2dAPI_InterCurveCurve_NbPoints(self, *args)

    def NbSegments(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of tangential intersections. nbsegments returns 0 if no intersections were found.

        Returns
        -------
        int

        """
        return _Geom2dAPI.Geom2dAPI_InterCurveCurve_NbSegments(self, *args)

    def Point(self, *args) -> "gp_Pnt2d":
        r"""
        Returns the intersection point of index index. intersection points are computed in case of cross intersections with a precision equal to the tolerance value assigned at the time of construction or in the function init (this value is defaulted to 1.0e-6). exceptions standard_outofrange if index is not in the range [ 1,nbpoints ], where nbpoints is the number of computed intersection points.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Pnt2d

        """
        return _Geom2dAPI.Geom2dAPI_InterCurveCurve_Point(self, *args)

    def Segment(self, *args) -> "void":
        r"""
        Use this syntax only to get solutions of tangential intersection between two curves. output values curve1 and curve2 are the intersection segments on the first curve and on the second curve accordingly. parameter index defines a number of computed solution. an intersection segment is a portion of an initial curve limited by two points. the distance from each point of this segment to the other curve is less or equal to the tolerance value assigned at the time of construction or in function init (this value is defaulted to 1.0e-6). exceptions standard_outofrange if index is not in the range [ 1,nbsegments ], where nbsegments is the number of computed tangential intersections. standard_nullobject if the algorithm is initialized for the computing of self-intersections on a curve.

        Parameters
        ----------
        Index: int
        Curve1: Geom2d_Curve
        Curve2: Geom2d_Curve

        Returns
        -------
        None

        """
        return _Geom2dAPI.Geom2dAPI_InterCurveCurve_Segment(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Geom2dAPI.delete_Geom2dAPI_InterCurveCurve

# Register Geom2dAPI_InterCurveCurve in _Geom2dAPI:
_Geom2dAPI.Geom2dAPI_InterCurveCurve_swigregister(Geom2dAPI_InterCurveCurve)

class Geom2dAPI_Interpolate(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Tolerance is to check if the points are not too close to one an other it is also used to check if the tangent vector is not too small. there should be at least 2 points if periodicflag is true then the curve will be periodic.

        Parameters
        ----------
        Points: TColgp_HArray1OfPnt2d
        PeriodicFlag: bool
        Tolerance: float

        Returns
        -------
        None
        If periodicflag is true then the curve will be periodic warning: there should be as many parameters as there are points except if periodicflag is true : then there should be one more parameter to close the curve.

        Parameters
        ----------
        Points: TColgp_HArray1OfPnt2d
        Parameters: TColStd_HArray1OfReal
        PeriodicFlag: bool
        Tolerance: float

        Returns
        -------
        None

        """
        _Geom2dAPI.Geom2dAPI_Interpolate_swiginit(self, _Geom2dAPI.new_Geom2dAPI_Interpolate(*args))

    def Curve(self, *args) -> "opencascade::handle< Geom2d_BSplineCurve > const &":
        r"""
        Returns the computed bspline curve. raises stdfail_notdone if the interpolation fails.

        Returns
        -------
        opencascade::handle<Geom2d_BSplineCurve>

        """
        return _Geom2dAPI.Geom2dAPI_Interpolate_Curve(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the constrained bspline curve is successfully constructed. note: in this case, the result is given by the function curve.

        Returns
        -------
        bool

        """
        return _Geom2dAPI.Geom2dAPI_Interpolate_IsDone(self, *args)

    def Load(self, *args) -> "void":
        r"""
        Assigns this constrained bspline curve to be tangential to vectors initialtangent and finaltangent at its first and last points respectively (i.e. the first and last points of the table of points through which the curve passes, as defined at the time of initialization). <scale> - boolean flag defining whether tangent vectors are to be scaled according to derivatives of lagrange interpolation.

        Parameters
        ----------
        InitialTangent: gp_Vec2d
        FinalTangent: gp_Vec2d
        Scale: bool,optional
        	default value is Standard_True

        Returns
        -------
        None
        Assigns this constrained bspline curve to be tangential to vectors defined in the table tangents, which is parallel to the table of points through which the curve passes, as defined at the time of initialization. vectors in the table tangents are defined only if the flag given in the parallel table tangentflags is true: only these vectors are set as tangency constraints. <scale> - boolean flag defining whether tangent vectors are to be scaled according to derivatives of lagrange interpolation.

        Parameters
        ----------
        Tangents: TColgp_Array1OfVec2d
        TangentFlags: TColStd_HArray1OfBoolean
        Scale: bool,optional
        	default value is Standard_True

        Returns
        -------
        None

        """
        return _Geom2dAPI.Geom2dAPI_Interpolate_Load(self, *args)

    def Perform(self, *args) -> "void":
        r"""
        Computes the constrained bspline curve. use the function isdone to verify that the computation is successful, and then the function curve to obtain the result.

        Returns
        -------
        None

        """
        return _Geom2dAPI.Geom2dAPI_Interpolate_Perform(self, *args)

    __repr__ = _dumps_object

    @methodnotwrapped
    def ClearTangents(self):
    	pass

    __swig_destroy__ = _Geom2dAPI.delete_Geom2dAPI_Interpolate

# Register Geom2dAPI_Interpolate in _Geom2dAPI:
_Geom2dAPI.Geom2dAPI_Interpolate_swigregister(Geom2dAPI_Interpolate)

class Geom2dAPI_PointsToBSpline(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs an empty approximation algorithm. use an init function to define and build the bspline curve.

        Returns
        -------
        None
        Approximate a bspline curve passing through an array of point. the resulting bspline will have the following properties: 1- his degree will be in the range [degmin,degmax] 2- his continuity will be at least <continuity> 3- the distance from the point <points> to the bspline will be lower to tol2d.

        Parameters
        ----------
        Points: TColgp_Array1OfPnt2d
        DegMin: int,optional
        	default value is 3
        DegMax: int,optional
        	default value is 8
        Continuity: GeomAbs_Shape,optional
        	default value is GeomAbs_C2
        Tol2D: float,optional
        	default value is 1.0e-6

        Returns
        -------
        None
        Approximate a bspline curve passing through an array of point. of coordinates : //! x = x0 + dx * (i-yvalues.lower()) y = yvalues(i) //! with i in the range yvalues.lower(), yvalues.upper() //! the bspline will be parametrized from t = x0 to x0 + dx * (yvalues.upper() - yvalues.lower()) //! and will satisfy x(t) = t //! the resulting bspline will have the following properties: 1- his degree will be in the range [degmin,degmax] 2- his continuity will be at least <continuity> 3- the distance from the point <points> to the bspline will be lower to tol2d.

        Parameters
        ----------
        YValues: TColStd_Array1OfReal
        X0: float
        DX: float
        DegMin: int,optional
        	default value is 3
        DegMax: int,optional
        	default value is 8
        Continuity: GeomAbs_Shape,optional
        	default value is GeomAbs_C2
        Tol2D: float,optional
        	default value is 1.0e-6

        Returns
        -------
        None
        Approximate a bspline curve passing through an array of point. the resulting bspline will have the following properties: 1- his degree will be in the range [degmin,degmax] 2- his continuity will be at least <continuity> 3- the distance from the point <points> to the bspline will be lower to tol2d.

        Parameters
        ----------
        Points: TColgp_Array1OfPnt2d
        ParType: Approx_ParametrizationType
        DegMin: int,optional
        	default value is 3
        DegMax: int,optional
        	default value is 8
        Continuity: GeomAbs_Shape,optional
        	default value is GeomAbs_C2
        Tol2D: float,optional
        	default value is 1.0e-3

        Returns
        -------
        None
        Approximate a bspline curve passing through an array of point, which parameters are given by the array <parameters>. the resulting bspline will have the following properties: 1- his degree will be in the range [degmin,degmax] 2- his continuity will be at least <continuity> 3- the distance from the point <points> to the bspline will be lower to tol2d.

        Parameters
        ----------
        Points: TColgp_Array1OfPnt2d
        Parameters: TColStd_Array1OfReal
        DegMin: int,optional
        	default value is 3
        DegMax: int,optional
        	default value is 8
        Continuity: GeomAbs_Shape,optional
        	default value is GeomAbs_C2
        Tol2D: float,optional
        	default value is 1.0e-3

        Returns
        -------
        None
        Approximate a bspline curve passing through an array of point using variational smoothing algorithm, which tries to minimize additional criterium: weight1*curvelength + weight2*curvature + weight3*torsion.

        Parameters
        ----------
        Points: TColgp_Array1OfPnt2d
        Weight1: float
        Weight2: float
        Weight3: float
        DegMax: int,optional
        	default value is 8
        Continuity: GeomAbs_Shape,optional
        	default value is GeomAbs_C2
        Tol3D: float,optional
        	default value is 1.0e-3

        Returns
        -------
        None

        """
        _Geom2dAPI.Geom2dAPI_PointsToBSpline_swiginit(self, _Geom2dAPI.new_Geom2dAPI_PointsToBSpline(*args))

    def Curve(self, *args) -> "opencascade::handle< Geom2d_BSplineCurve > const &":
        r"""
        Returns the approximate bspline curve.

        Returns
        -------
        opencascade::handle<Geom2d_BSplineCurve>

        """
        return _Geom2dAPI.Geom2dAPI_PointsToBSpline_Curve(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Approximate a bspline curve passing through an array of point. the resulting bspline will have the following properties: 1- his degree will be in the range [degmin,degmax] 2- his continuity will be at least <continuity> 3- the distance from the point <points> to the bspline will be lower to tol2d.

        Parameters
        ----------
        Points: TColgp_Array1OfPnt2d
        DegMin: int,optional
        	default value is 3
        DegMax: int,optional
        	default value is 8
        Continuity: GeomAbs_Shape,optional
        	default value is GeomAbs_C2
        Tol2D: float,optional
        	default value is 1.0e-6

        Returns
        -------
        None
        Approximate a bspline curve passing through an array of point. of coordinates : //! x = x0 + dx * (i-yvalues.lower()) y = yvalues(i) //! with i in the range yvalues.lower(), yvalues.upper() //! the bspline will be parametrized from t = x0 to x0 + dx * (yvalues.upper() - yvalues.lower()) //! and will satisfy x(t) = t //! the resulting bspline will have the following properties: 1- his degree will be in the range [degmin,degmax] 2- his continuity will be at least <continuity> 3- the distance from the point <points> to the bspline will be lower to tol2d.

        Parameters
        ----------
        YValues: TColStd_Array1OfReal
        X0: float
        DX: float
        DegMin: int,optional
        	default value is 3
        DegMax: int,optional
        	default value is 8
        Continuity: GeomAbs_Shape,optional
        	default value is GeomAbs_C2
        Tol2D: float,optional
        	default value is 1.0e-6

        Returns
        -------
        None
        Approximate a bspline curve passing through an array of point. the resulting bspline will have the following properties: 1- his degree will be in the range [degmin,degmax] 2- his continuity will be at least <continuity> 3- the distance from the point <points> to the bspline will be lower to tol2d.

        Parameters
        ----------
        Points: TColgp_Array1OfPnt2d
        ParType: Approx_ParametrizationType
        DegMin: int,optional
        	default value is 3
        DegMax: int,optional
        	default value is 8
        Continuity: GeomAbs_Shape,optional
        	default value is GeomAbs_C2
        Tol2D: float,optional
        	default value is 1.0e-3

        Returns
        -------
        None
        Approximate a bspline curve passing through an array of point, which parameters are given by the array <parameters>. the resulting bspline will have the following properties: 1- his degree will be in the range [degmin,degmax] 2- his continuity will be at least <continuity> 3- the distance from the point <points> to the bspline will be lower to tol2d.

        Parameters
        ----------
        Points: TColgp_Array1OfPnt2d
        Parameters: TColStd_Array1OfReal
        DegMin: int,optional
        	default value is 3
        DegMax: int,optional
        	default value is 8
        Continuity: GeomAbs_Shape,optional
        	default value is GeomAbs_C2
        Tol2D: float,optional
        	default value is 1.0e-3

        Returns
        -------
        None
        Approximate a bspline curve passing through an array of point using variational smoothing algorithm, which tries to minimize additional criterium: weight1*curvelength + weight2*curvature + weight3*torsion.

        Parameters
        ----------
        Points: TColgp_Array1OfPnt2d
        Weight1: float
        Weight2: float
        Weight3: float
        DegMax: int,optional
        	default value is 8
        Continuity: GeomAbs_Shape,optional
        	default value is GeomAbs_C2
        Tol2D: float,optional
        	default value is 1.0e-3

        Returns
        -------
        None

        """
        return _Geom2dAPI.Geom2dAPI_PointsToBSpline_Init(self, *args)

    def IsDone(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Returns
        -------
        bool

        """
        return _Geom2dAPI.Geom2dAPI_PointsToBSpline_IsDone(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Geom2dAPI.delete_Geom2dAPI_PointsToBSpline

# Register Geom2dAPI_PointsToBSpline in _Geom2dAPI:
_Geom2dAPI.Geom2dAPI_PointsToBSpline_swigregister(Geom2dAPI_PointsToBSpline)

class Geom2dAPI_ProjectPointOnCurve(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Constructs an empty projector algorithm. use an init function to define the point and the curve on which it is going to work.

        Returns
        -------
        None
        Create the projection of a point <p> on a curve <curve>.

        Parameters
        ----------
        P: gp_Pnt2d
        Curve: Geom2d_Curve

        Returns
        -------
        None
        Create the projection of a point <p> on a curve <curve> limited by the two points of parameter umin and usup. warning use the function nbpoints to obtain the number of solutions. if projection fails, nbpoints returns 0.

        Parameters
        ----------
        P: gp_Pnt2d
        Curve: Geom2d_Curve
        Umin: float
        Usup: float

        Returns
        -------
        None

        """
        _Geom2dAPI.Geom2dAPI_ProjectPointOnCurve_swiginit(self, _Geom2dAPI.new_Geom2dAPI_ProjectPointOnCurve(*args))

    def Distance(self, *args) -> "Standard_Real":
        r"""
        Computes the distance between the point and its computed orthogonal projection on the curve. index is a number of computed projected point. exceptions standard_outofrange if index is not in the range [ 1,nbpoints ], where nbpoints is the number of solution points.

        Parameters
        ----------
        Index: int

        Returns
        -------
        float

        """
        return _Geom2dAPI.Geom2dAPI_ProjectPointOnCurve_Distance(self, *args)

    def Extrema(self, *args) -> "Extrema_ExtPC2d const &":
        r"""
        Return the algorithmic object from extrema.

        Returns
        -------
        Extrema_ExtPC2d

        """
        return _Geom2dAPI.Geom2dAPI_ProjectPointOnCurve_Extrema(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initializes this algorithm with the given arguments, and computes the orthogonal projections of a point <p> on a curve <curve>.

        Parameters
        ----------
        P: gp_Pnt2d
        Curve: Geom2d_Curve

        Returns
        -------
        None
        Initializes this algorithm with the given arguments, and computes the orthogonal projections of the point p onto the portion of the curve curve limited by the two points of parameter umin and usup.

        Parameters
        ----------
        P: gp_Pnt2d
        Curve: Geom2d_Curve
        Umin: float
        Usup: float

        Returns
        -------
        None

        """
        return _Geom2dAPI.Geom2dAPI_ProjectPointOnCurve_Init(self, *args)

    def LowerDistance(self, *args) -> "Standard_Real":
        r"""
        Computes the distance between the point and its nearest orthogonal projection on the curve. exceptions stdfail_notdone if this algorithm fails.

        Returns
        -------
        float

        """
        return _Geom2dAPI.Geom2dAPI_ProjectPointOnCurve_LowerDistance(self, *args)

    def LowerDistanceParameter(self, *args) -> "Standard_Real":
        r"""
        Returns the parameter on the curve of the nearest orthogonal projection of the point. exceptions stdfail_notdone if this algorithm fails.

        Returns
        -------
        float

        """
        return _Geom2dAPI.Geom2dAPI_ProjectPointOnCurve_LowerDistanceParameter(self, *args)

    def NbPoints(self, *args) -> "Standard_Integer":
        r"""
        Return the number of of computed orthogonal projectionn points.

        Returns
        -------
        int

        """
        return _Geom2dAPI.Geom2dAPI_ProjectPointOnCurve_NbPoints(self, *args)

    def NearestPoint(self, *args) -> "gp_Pnt2d":
        r"""
        Returns the nearest orthogonal projection of the point on the curve. exceptions stdfail_notdone if this algorithm fails.

        Returns
        -------
        gp_Pnt2d

        """
        return _Geom2dAPI.Geom2dAPI_ProjectPointOnCurve_NearestPoint(self, *args)

    def Parameter(self, *args) -> "void":
        r"""
        Returns the parameter on the curve of a point which is the orthogonal projection. index is a number of a computed projected point. exceptions standard_outofrange if index is not in the range [ 1,nbpoints ], where nbpoints is the number of solution points.

        Parameters
        ----------
        Index: int

        Returns
        -------
        float
        Returns the parameter on the curve of a point which is the orthogonal projection. index is a number of a computed projected point. exceptions standard_outofrange if index is not in the range [ 1,nbpoints ], where nbpoints is the number of solution points.

        Parameters
        ----------
        Index: int

        Returns
        -------
        U: float

        """
        return _Geom2dAPI.Geom2dAPI_ProjectPointOnCurve_Parameter(self, *args)

    def Point(self, *args) -> "gp_Pnt2d":
        r"""
        Returns the orthogonal projection on the curve. index is a number of a computed point. exceptions standard_outofrange if index is not in the range [ 1,nbpoints ], where nbpoints is the number of solution points.

        Parameters
        ----------
        Index: int

        Returns
        -------
        gp_Pnt2d

        """
        return _Geom2dAPI.Geom2dAPI_ProjectPointOnCurve_Point(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _Geom2dAPI.delete_Geom2dAPI_ProjectPointOnCurve

# Register Geom2dAPI_ProjectPointOnCurve in _Geom2dAPI:
_Geom2dAPI.Geom2dAPI_ProjectPointOnCurve_swigregister(Geom2dAPI_ProjectPointOnCurve)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.StepShape import *
from OCC.Core.Interface import *
from OCC.Core.StepRepr import *
from OCC.Core.StepBasic import *
from OCC.Core.IFSelect import *
from OCC.Core.TCollection import *
from OCC.Core.XSControl import *


class STEPSelections_SequenceOfAssemblyComponent:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class STEPSelections_SequenceOfAssemblyLink:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class STEPSelections_AssemblyComponent(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, sdr: StepShape_ShapeDefinitionRepresentation, list: STEPSelections_HSequenceOfAssemblyLink) -> None: ...
	def GetList(self) -> STEPSelections_HSequenceOfAssemblyLink: ...
	def GetSDR(self) -> StepShape_ShapeDefinitionRepresentation: ...
	def SetList(self, list: STEPSelections_HSequenceOfAssemblyLink) -> None: ...
	def SetSDR(self, sdr: StepShape_ShapeDefinitionRepresentation) -> None: ...

class STEPSelections_AssemblyExplorer:
	def __init__(self, G: Interface_Graph) -> None: ...
	def FillListWithGraph(self, cmp: STEPSelections_AssemblyComponent) -> None: ...
	def FindItemWithNAUO(self, nauo: StepRepr_NextAssemblyUsageOccurrence) -> Standard_Transient: ...
	def FindSDRWithProduct(self, product: StepBasic_ProductDefinition) -> StepShape_ShapeDefinitionRepresentation: ...
	def Init(self, G: Interface_Graph) -> None: ...
	def NbAssemblies(self) -> int: ...
	def Root(self, rank: Optional[int] = 1) -> STEPSelections_AssemblyComponent: ...

class STEPSelections_AssemblyLink(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, nauo: StepRepr_NextAssemblyUsageOccurrence, item: Standard_Transient, part: STEPSelections_AssemblyComponent) -> None: ...
	def GetComponent(self) -> STEPSelections_AssemblyComponent: ...
	def GetItem(self) -> Standard_Transient: ...
	def GetNAUO(self) -> StepRepr_NextAssemblyUsageOccurrence: ...
	def SetComponent(self, part: STEPSelections_AssemblyComponent) -> None: ...
	def SetItem(self, item: Standard_Transient) -> None: ...
	def SetNAUO(self, nauo: StepRepr_NextAssemblyUsageOccurrence) -> None: ...

class STEPSelections_Counter:
	def __init__(self) -> None: ...
	def Clear(self) -> None: ...
	def Count(self, graph: Interface_Graph, start: Standard_Transient) -> None: ...
	def NbInstancesOfEdges(self) -> int: ...
	def NbInstancesOfFaces(self) -> int: ...
	def NbInstancesOfShells(self) -> int: ...
	def NbInstancesOfSolids(self) -> int: ...
	def NbInstancesOfWires(self) -> int: ...
	def NbSourceEdges(self) -> int: ...
	def NbSourceFaces(self) -> int: ...
	def NbSourceShells(self) -> int: ...
	def NbSourceSolids(self) -> int: ...
	def NbSourceWires(self) -> int: ...

class STEPSelections_SelectAssembly(IFSelect_SelectExplore):
	def __init__(self) -> None: ...
	def Explore(self, level: int, ent: Standard_Transient, G: Interface_Graph, explored: Interface_EntityIterator) -> bool: ...
	def ExploreLabel(self) -> TCollection_AsciiString: ...

class STEPSelections_SelectDerived(StepSelect_StepType):
	def __init__(self) -> None: ...
	def Matches(self, ent: Standard_Transient, model: Interface_InterfaceModel, text: TCollection_AsciiString, exact: bool) -> bool: ...

class STEPSelections_SelectFaces(IFSelect_SelectExplore):
	def __init__(self) -> None: ...
	def Explore(self, level: int, ent: Standard_Transient, G: Interface_Graph, explored: Interface_EntityIterator) -> bool: ...
	def ExploreLabel(self) -> TCollection_AsciiString: ...

class STEPSelections_SelectForTransfer(XSControl_SelectForTransfer):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, TR: XSControl_TransferReader) -> None: ...
	def RootResult(self, G: Interface_Graph) -> Interface_EntityIterator: ...

class STEPSelections_SelectGSCurves(IFSelect_SelectExplore):
	def __init__(self) -> None: ...
	def Explore(self, level: int, ent: Standard_Transient, G: Interface_Graph, explored: Interface_EntityIterator) -> bool: ...
	def ExploreLabel(self) -> TCollection_AsciiString: ...

class STEPSelections_SelectInstances(IFSelect_SelectExplore):
	def __init__(self) -> None: ...
	def Explore(self, level: int, ent: Standard_Transient, G: Interface_Graph, explored: Interface_EntityIterator) -> bool: ...
	def ExploreLabel(self) -> TCollection_AsciiString: ...
	def RootResult(self, G: Interface_Graph) -> Interface_EntityIterator: ...

# harray1 classes
# harray2 classes
# hsequence classes

class STEPSelections_HSequenceOfAssemblyLink(STEPSelections_SequenceOfAssemblyLink, Standard_Transient):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: STEPSelections_SequenceOfAssemblyLink) -> None: ...
    def Sequence(self) -> STEPSelections_SequenceOfAssemblyLink: ...
    def Append(self, theSequence: STEPSelections_SequenceOfAssemblyLink) -> None: ...


